@@ -222,7 +222,12 @@ def create(request, content_type_app_name, content_type_model_name, parent_page_
                 if hasattr(result, 'status_code'):
                     return result
 
-            return redirect('wagtailadmin_explore', page.get_parent().id)
+            if is_publishing or is_submitting:
+                # we're done here - redirect back to the explorer
+                return redirect('wagtailadmin_explore', page.get_parent().id)
+            else:
+                # Just saving - remain on edit page for further edits
+                return redirect('wagtailadmin_pages_edit', page.id)
         else:
             messages.error(request, _("The page could not be created due to validation errors"))
             edit_handler = edit_handler_class(instance=page, form=form)
@@ -332,7 +337,12 @@ def edit(request, page_id):
                 if hasattr(result, 'status_code'):
                     return result
 
-            return redirect('wagtailadmin_explore', page.get_parent().id)
+            if is_publishing or is_submitting:
+                # we're done here - redirect back to the explorer
+                return redirect('wagtailadmin_explore', page.get_parent().id)
+            else:
+                # Just saving - remain on edit page for further edits
+                return redirect('wagtailadmin_pages_edit', page.id)
         else:
             if page.locked:
                 messages.error(request, _("The page could not be saved as it is locked"))
@@ -363,7 +373,7 @@ def edit(request, page_id):
 
 @permission_required('wagtailadmin.access_admin')
 def delete(request, page_id):
-    page = get_object_or_404(Page, id=page_id)
+    page = get_object_or_404(Page, id=page_id).specific
     if not page.permissions_for_user(request.user).can_delete():
         raise PermissionDenied
 
@@ -500,7 +510,7 @@ def preview_loading(request):
 
 @permission_required('wagtailadmin.access_admin')
 def unpublish(request, page_id):
-    page = get_object_or_404(Page, id=page_id)
+    page = get_object_or_404(Page, id=page_id).specific
     if not page.permissions_for_user(request.user).can_unpublish():
         raise PermissionDenied
 
@@ -548,7 +558,7 @@ def move_choose_destination(request, page_to_move_id, viewed_page_id=None):
 
 @permission_required('wagtailadmin.access_admin')
 def move_confirm(request, page_to_move_id, destination_id):
-    page_to_move = get_object_or_404(Page, id=page_to_move_id)
+    page_to_move = get_object_or_404(Page, id=page_to_move_id).specific
     destination = get_object_or_404(Page, id=destination_id)
     if not page_to_move.permissions_for_user(request.user).can_move_to(destination):
         raise PermissionDenied
@@ -631,16 +641,10 @@ def copy(request, page_id):
             update_attrs={
                 'title': form.cleaned_data['new_title'],
                 'slug': form.cleaned_data['new_slug'],
-            }
+            },
+            keep_live=(can_publish and form.cleaned_data.get('publish_copies')),
         )
 
-        # Check if we should keep copied subpages published
-        publish_copies = can_publish and form.cleaned_data.get('publish_copies')
-
-        # Unpublish copied pages if we need to
-        if not publish_copies:
-            new_page.get_descendants(inclusive=True).unpublish()
-
         # Assign user of this request as the owner of all the new pages
         new_page.get_descendants(inclusive=True).update(owner=request.user)
 
@@ -775,7 +779,7 @@ def preview_for_moderation(request, revision_id):
 @require_POST
 def lock(request, page_id):
     # Get the page
-    page = get_object_or_404(Page, id=page_id)
+    page = get_object_or_404(Page, id=page_id).specific
 
     # Check permissions
     if not page.permissions_for_user(request.user).can_lock():
@@ -786,6 +790,8 @@ def lock(request, page_id):
         page.locked = True
         page.save()
 
+        messages.success(request, _("Page '{0}' is now locked.").format(page.title))
+
     # Redirect
     redirect_to = request.POST.get('next', None)
     if redirect_to and is_safe_url(url=redirect_to, host=request.get_host()):
@@ -798,7 +804,7 @@ def lock(request, page_id):
 @require_POST
 def unlock(request, page_id):
     # Get the page
-    page = get_object_or_404(Page, id=page_id)
+    page = get_object_or_404(Page, id=page_id).specific
 
     # Check permissions
     if not page.permissions_for_user(request.user).can_lock():
@@ -809,6 +815,8 @@ def unlock(request, page_id):
         page.locked = False
         page.save()
 
+        messages.success(request, _("Page '{0}' is now unlocked.").format(page.title))
+
     # Redirect
     redirect_to = request.POST.get('next', None)
     if redirect_to and is_safe_url(url=redirect_to, host=request.get_host()):
