@@ -1,9 +1,5 @@
-from django.conf import settings
-try:
-    from importlib import import_module
-except ImportError:
-    # for Python 2.6, fall back on django.utils.importlib (deprecated as of Django 1.7)
-    from django.utils.importlib import import_module
+from wagtail.utils.apps import get_app_submodules
+
 
 _hooks = {}
 
@@ -40,12 +36,7 @@ _searched_for_hooks = False
 def search_for_hooks():
     global _searched_for_hooks
     if not _searched_for_hooks:
-        for app_module in settings.INSTALLED_APPS:
-            try:
-                import_module('%s.wagtail_hooks' % app_module)
-            except ImportError:
-                continue
-
+        list(get_app_submodules('wagtail_hooks'))
         _searched_for_hooks = True
 
 
