@@ -15,8 +15,8 @@ class Command(BaseCommand):
         pages = from_page.get_children()
 
         # Move the pages
-        print 'Moving ' + str(len(pages)) + ' pages from "' + from_page.title + '" to "' + to_page.title + '"'
+        self.stdout.write('Moving ' + str(len(pages)) + ' pages from "' + from_page.title + '" to "' + to_page.title + '"')
         for page in pages:
             page.move(to_page, pos='last-child')
 
-        print 'Done'
+        self.stdout.write('Done')
