@@ -508,13 +508,29 @@ class TestBackendConfiguration(TestCase):
     def test_urls(self):
         # This test backwards compatibility with old URLS setting
         backend = self.ElasticSearch(params={
-            'URLS': ['http://localhost:12345', 'https://127.0.0.1:54321'],
+            'URLS': [
+                'http://localhost:12345',
+                'https://127.0.0.1:54321',
+                'http://username:password@elasticsearch.mysite.com',
+                'https://elasticsearch.mysite.com/hello',
+            ],
         })
 
-        self.assertEqual(len(backend.es_hosts), 2)
+        self.assertEqual(len(backend.es_hosts), 4)
         self.assertEqual(backend.es_hosts[0]['host'], 'localhost')
         self.assertEqual(backend.es_hosts[0]['port'], 12345)
         self.assertEqual(backend.es_hosts[0]['use_ssl'], False)
+
         self.assertEqual(backend.es_hosts[1]['host'], '127.0.0.1')
         self.assertEqual(backend.es_hosts[1]['port'], 54321)
         self.assertEqual(backend.es_hosts[1]['use_ssl'], True)
+
+        self.assertEqual(backend.es_hosts[2]['host'], 'elasticsearch.mysite.com')
+        self.assertEqual(backend.es_hosts[2]['port'], 80)
+        self.assertEqual(backend.es_hosts[2]['use_ssl'], False)
+        self.assertEqual(backend.es_hosts[2]['http_auth'], ('username', 'password'))
+
+        self.assertEqual(backend.es_hosts[3]['host'], 'elasticsearch.mysite.com')
+        self.assertEqual(backend.es_hosts[3]['port'], 443)
+        self.assertEqual(backend.es_hosts[3]['use_ssl'], True)
+        self.assertEqual(backend.es_hosts[3]['url_prefix'], '/hello')
