@@ -1,13 +1,12 @@
 from django import forms
 
 from wagtail.wagtailcore.models import Site
-from wagtail.wagtailadmin.widgets import AdminPageChooser
 
 
 class SiteForm(forms.ModelForm):
     def __init__(self, *args, **kwargs):
         super(SiteForm, self).__init__(*args, **kwargs)
-        self.fields['root_page'].widget = AdminPageChooser()
+        self.fields['root_page'].widget = forms.HiddenInput()
 
     required_css_class = "required"
 
