@@ -5,7 +5,6 @@ from django.contrib.auth import get_user_model
 from django.contrib.auth.models import Group, Permission
 
 from wagtail.wagtailcore import hooks
-from wagtail.wagtailadmin.widgets import AdminPageChooser
 from wagtail.wagtailusers.models import UserProfile
 from wagtail.wagtailcore.models import UserPagePermissionsProxy, GroupPagePermission
 
@@ -192,7 +191,7 @@ class GroupForm(forms.ModelForm):
 class GroupPagePermissionForm(forms.ModelForm):
     def __init__(self, *args, **kwargs):
         super(GroupPagePermissionForm, self).__init__(*args, **kwargs)
-        self.fields['page'].widget = AdminPageChooser()
+        self.fields['page'].widget = forms.HiddenInput()
 
     class Meta:
         model = GroupPagePermission
